@@ -80,8 +80,8 @@ plot.vblpcm<-function(x, ..., R2=0.2, main="Variational-Bayes Positions", alpha=
   plot_func<-function(x) vblpcmdrawpie(center=x[1:2], radius=x[2+1], probs=x[(2+2):(2+1+G)], n = 20, colours=colours)
   apply(plot_matrix, 1, plot_func)
   points(V_eta_2D, col=colours, pch=3)
-  #symbols(V_eta_2D, circles=sqrt(V_alpha*x$sigma02), add=1, fg=colours, inches=FALSE)
-  symbols(V_eta_2D, circles=sqrt(x$V_lambda%*%x$V_sigma2*x$sigma02), add=1, fg=colours, inches=FALSE)
+  symbols(V_eta_2D, circles=2*sqrt(1/(x$inv_sigma02*x$V_alpha)), add=1, fg=colours, inches=FALSE)
+  #symbols(V_eta_2D, circles=sqrt(x$V_lambda%*%x$V_sigma2*x$sigma02), add=1, fg=colours, inches=FALSE)
   #points(0,0,pch=3)
   if (RET) 
     return(list(positions=V_z_2D,clusters=V_eta_2D))
